@@ -972,7 +972,7 @@ impl StateHub {
     }
 
     async fn check_for_update(&self) {
-        if !self.json {
+        if !self.json && Config::more_than_one_day_passed_since_last_check() {
             self.check_for_update_helper()
                 .await
                 .and_then(|(current, latest)| {
@@ -982,6 +982,7 @@ impl StateHub {
                     ))
                     .ok()
                 });
+            Config::touch_update();
         }
     }
 
