@@ -115,8 +115,8 @@ impl Show for Cluster {
     }
 
     fn detailed_show(&self) -> String {
-        let helm = k8s::Helm::new("statehub-system".to_string(), None, true);
-        let helm = helm.command(self);
+        let helm = k8s::Helm::new(true);
+        let helm = helm.command(self, "statehub-system");
         format!(
             "{}\n{}\n{}\n{}\n{}\n{}",
             format_args!("Cluster:     {}", self.name),
